==> estateplat-common-1.2.3-20180108.011417-6-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfMmhtFwqsgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "fcjy_clf_mmht_fwqsgk")
public class FcjyClfMmhtFwqsgk implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String fwlx;//房屋类型
    private String fwjg;//房屋结构
    private String hx;//户型
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private String syqr;//所有权人
    private String syqzh;//所有权证号
    private Double symj;//使用面积
    private Double ftmj;//分摊面积
    private String ghyt;//规划用途
    private String zcs;//总层数
    private Integer jcnf;//建成年份
    private String fwxzqtsm;//房屋现状其他说明
    private String tdsyqr;//土地使用权人
    private String tdsyqzh;//土地使用权证号
    private String tdsyqlx;//土地使用权类型
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double zdmj;//土地使用权面积
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String bz;//备注

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public String getSyqr() {
        return syqr;
    }

    public void setSyqr(String syqr) {
        this.syqr = syqr;
    }

    public String getSyqzh() {
        return syqzh;
    }

    public void setSyqzh(String syqzh) {
        this.syqzh = syqzh;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public Integer getJcnf() {
        return jcnf;
    }

    public void setJcnf(Integer jcnf) {
        this.jcnf = jcnf;
    }

    public String getFwxzqtsm() {
        return fwxzqtsm;
    }

    public void setFwxzqtsm(String fwxzqtsm) {
        this.fwxzqtsm = fwxzqtsm;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }
}

==> estateplat-common-1.2.3-20180201.032946-23-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfMmhtFwqsgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "fcjy_clf_mmht_fwqsgk")
public class FcjyClfMmhtFwqsgk implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String fwlx;//房屋类型
    private String fwjg;//房屋结构
    private String hx;//户型
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private String syqr;//所有权人
    private String syqzh;//所有权证号
    private Double symj;//使用面积
    private Double ftmj;//分摊面积
    private String ghyt;//规划用途
    private String zcs;//总层数
    private Integer jcnf;//建成年份
    private String fwxzqtsm;//房屋现状其他说明
    private String tdsyqr;//土地使用权人
    private String tdsyqzh;//土地使用权证号
    private String tdsyqlx;//土地使用权类型
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double zdmj;//土地使用权面积
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String fwxz;//房屋性质
    private String yfwxz;//原房屋性质
    private String bz;//备注


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public String getSyqr() {
        return syqr;
    }

    public void setSyqr(String syqr) {
        this.syqr = syqr;
    }

    public String getSyqzh() {
        return syqzh;
    }

    public void setSyqzh(String syqzh) {
        this.syqzh = syqzh;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public Integer getJcnf() {
        return jcnf;
    }

    public void setJcnf(Integer jcnf) {
        this.jcnf = jcnf;
    }

    public String getFwxzqtsm() {
        return fwxzqtsm;
    }

    public void setFwxzqtsm(String fwxzqtsm) {
        this.fwxzqtsm = fwxzqtsm;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }
}
